@@ -7,7 +7,7 @@ package Data::Dump::Color;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-06-24'; # DATE
 our $DIST = 'Data-Dump-Color'; # DIST
-our $VERSION = '0.247'; # VERSION
+our $VERSION = '0.248'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -784,7 +784,7 @@ Data::Dump::Color - Like Data::Dump, but with color
 
 =head1 VERSION
 
-This document describes version 0.247 of Data::Dump::Color (from Perl distribution Data-Dump-Color), released on 2021-06-24.
+This document describes version 0.248 of Data::Dump::Color (from Perl distribution Data-Dump-Color), released on 2021-06-24.
 
 =head1 SYNOPSIS
 
@@ -794,6 +794,14 @@ Use it like you would Data::Dump, e.g.:
 
 =head1 DESCRIPTION
 
+Sample screenshot:
+
+=for Pod::Coverage ^(dumpf|pp|quote|squote|tied_str|fullname|format_list|str|looks_like_number|max)$
+
+=for html <img src="https://st.aticpan.org/source/PERLANCAR/Data-Dump-Color-0.248/share/images/Screenshot_20210624_071713.png" />
+
+=for html <img src="https://st.aticpan.org/source/PERLANCAR/Data-Dump-Color-0.248/share/images/Screenshot_20210624_071341.png" />
+
 This module aims to be a drop-in replacement for L<Data::Dump>. It adds colors
 to dumps. It also adds various visual aids in the comments, e.g. array/hash
 index, depth indicator, and so on.
@@ -801,8 +809,6 @@ index, depth indicator, and so on.
 For more information, see Data::Dump. This documentation explains what's
 different between this module and Data::Dump.
 
-=for Pod::Coverage ^(dumpf|pp|quote|squote|tied_str|fullname|format_list|str|looks_like_number|max)$
-
 =head1 RESULTS
 
 By default Data::Dump::Color shows array index or hash pair sequence in comments
